#[non_exhaustive]pub struct OffsetCommitRequest {
pub group_id: String,
pub generation_id_or_member_epoch: Option<i32>,
pub member_id: Option<String>,
pub group_instance_id: Option<String>,
pub retention_time_ms: Option<i64>,
pub topics: Option<Vec<OffsetCommitRequestTopic>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_id: StringThe unique group identifier.
generation_id_or_member_epoch: Option<i32>The generation of the group if using the classic group protocol or the member epoch if using the consumer protocol.
member_id: Option<String>The member ID assigned by the group coordinator.
group_instance_id: Option<String>The unique identifier of the consumer instance provided by end user.
retention_time_ms: Option<i64>The time period in ms to retain the offset.
topics: Option<Vec<OffsetCommitRequestTopic>>The topics to commit offsets for.
Implementations
Sourceimpl OffsetCommitRequest
impl OffsetCommitRequest
pub fn group_id(self, group_id: String) -> Self
pub fn generation_id_or_member_epoch( self, generation_id_or_member_epoch: Option<i32>, ) -> Self
pub fn member_id(self, member_id: Option<String>) -> Self
pub fn group_instance_id(self, group_instance_id: Option<String>) -> Self
pub fn retention_time_ms(self, retention_time_ms: Option<i64>) -> Self
pub fn topics(self, topics: Option<Vec<OffsetCommitRequestTopic>>) -> Self