#[non_exhaustive]pub struct OffsetCommitResponse {
pub throttle_time_ms: Option<i32>,
pub topics: Option<Vec<OffsetCommitResponseTopic>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.throttle_time_ms: Option<i32>The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
topics: Option<Vec<OffsetCommitResponseTopic>>The responses for each topic.
Implementations
Sourceimpl OffsetCommitResponse
impl OffsetCommitResponse
pub fn throttle_time_ms(self, throttle_time_ms: Option<i32>) -> Self
pub fn topics(self, topics: Option<Vec<OffsetCommitResponseTopic>>) -> Self