#[non_exhaustive]pub struct FeatureUpdateKey {
pub feature: String,
pub max_version_level: i16,
pub allow_downgrade: Option<bool>,
pub upgrade_type: Option<i8>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.feature: StringThe name of the finalized feature to be updated.
max_version_level: i16The new maximum version level for the finalized feature. A value >= 1 is valid. A value < 1, is special, and can be used to request the deletion of the finalized feature.
allow_downgrade: Option<bool>DEPRECATED in version 1 (see DowngradeType). When set to true, the finalized feature version level is allowed to be downgraded/deleted. The downgrade request will fail if the new maximum version level is a value that’s not lower than the existing maximum finalized version level.
upgrade_type: Option<i8>Determine which type of upgrade will be performed: 1 will perform an upgrade only (default), 2 is safe downgrades only (lossless), 3 is unsafe downgrades (lossy).
Implementations
Sourceimpl FeatureUpdateKey
impl FeatureUpdateKey
pub fn feature(self, feature: String) -> Self
pub fn max_version_level(self, max_version_level: i16) -> Self
pub fn allow_downgrade(self, allow_downgrade: Option<bool>) -> Self
pub fn upgrade_type(self, upgrade_type: Option<i8>) -> Self